@@ -1,4 +1,6 @@
 import shutil
+import typing
+
 from pathlib import Path
 from datetime import datetime
 
@@ -13,32 +15,26 @@ def clear_dags_output_dir(workdir: str):
 def generate_dag_file(workdir: str,
                       docker_repository: str,
                       workflow,
-                      start_from: str,
+                      start_from: typing.Union[datetime, str],
                       build_ver: str,
                       root_package_name: str) -> str:
-    print('creating DAG file ...')
+    start_from = _str_to_datetime(start_from)
+
     print(f'start_from: {start_from}')
-    print(f'workdir: {workdir}')
     print(f'build_ver: {build_ver}')
     print(f'docker_repository: {docker_repository}')
 
     dag_deployment_id = get_dag_deployment_id(workflow.workflow_id, start_from, build_ver)
     dag_file_path = get_dags_output_dir(workdir) / (dag_deployment_id + '_dag.py')
-
-    if workflow.schedule_interval == '@daily':
-        start_from = start_from[:10]
-        start_date_as_str = f'datetime.strptime("{start_from}", "%Y-%m-%d")'
-    else:
-        start_date_as_str = f'datetime.strptime("{start_from}", "%Y-%m-%d %H:%M:%S") - (timedelta(seconds={get_timezone_offset_seconds()}))'
+    start_date_as_str = repr(workflow.start_time_factory(start_from))
 
     print(f'dag_file_path: {dag_file_path.resolve()}')
 
     dag_chunks = []
 
-    dag_chunks.append("""    
+    dag_chunks.append("""
+import datetime
 from airflow import DAG
-from datetime import timedelta
-from datetime import datetime
 from airflow.contrib.operators import kubernetes_pod_operator
 
 default_args = {{
@@ -47,7 +43,7 @@ default_args = {{
             'start_date': {start_date_as_str},
             'email_on_failure': False,
             'email_on_retry': False,
-            'execution_timeout': timedelta(minutes=90)
+            'execution_timeout': datetime.timedelta(minutes=180),
 }}
 
 dag = DAG(
@@ -73,31 +69,28 @@ dag = DAG(
     task_id='{task_id}',
     name='{task_id}',
     cmds=['bf'],
-    arguments=['run', '--job', '{bf_job}', '--runtime', '{{{{ execution_date.strftime("%Y-%m-%d %H:%M:%S") }}}}', '--root', '{root_folder}', '--config', '{{{{var.value.env}}}}'],
+    arguments=['run', '--job', '{bf_job}', '--runtime', '{{{{ execution_date.strftime("%Y-%m-%d %H:%M:%S") }}}}', '--project-package', '{root_folder}', '--config', '{{{{var.value.env}}}}'],
     namespace='default',
     image='{docker_image}',
     is_delete_operator_pod=True,
     retries={retries},
-    retry_delay= timedelta(seconds={retry_delay}),
-    dag=dag)            
+    retry_delay=datetime.timedelta(seconds={retry_delay}),
+    dag=dag)
 """.format(job_var=job_var,
           task_id=task_id,
           docker_image = docker_repository+":"+build_ver,
           bf_job= workflow.workflow_id+"."+job.id,
           root_folder=root_package_name,
-          retries=job.retry_count,
-          retry_delay=job.retry_pause_sec)
-)
+          retries=job.retry_count if hasattr(job, 'retry_count') else 3,
+          retry_delay=job.retry_pause_sec if hasattr(job, 'retry_pause_sec') else 60))
 
         for d in dependencies:
             up_job_var = "t" + str(get_job(d).id)
             dag_chunks.append("{job_var}.set_upstream({up_job_var})".format(job_var=job_var, up_job_var=up_job_var))
 
-
     workflow.call_on_graph_nodes(build_dag_operator)
 
     dag_file_content = '\n'.join(dag_chunks) + '\n'
-    print (dag_file_content)
     dag_file_path.write_text(dag_file_content)
 
     return dag_file_path.as_posix()
@@ -109,18 +102,23 @@ def get_dag_deployment_id(workflow_name: str,
     return '{workflow_name}__v{ver}__{start_from}'.format(
         workflow_name=workflow_name,
         ver=build_ver.replace('.','_').replace('-','_'),
-        start_from=datetime.strptime(start_from, "%Y-%m-%d" if len(start_from) <= 10 else "%Y-%m-%d %H:%M:%S").strftime('%Y_%m_%d_%H_%M_%S')
+        start_from=_str_to_datetime(start_from).strftime('%Y_%m_%d_%H_%M_%S')
     )
 
 
-def get_timezone_offset_seconds() -> str:
-    return str(datetime.now().astimezone().tzinfo.utcoffset(None).seconds)
-
-
 def get_dags_output_dir(workdir: str) -> Path:
     dags_dir_path = Path(workdir) / '.dags'
 
     if not dags_dir_path.exists():
         dags_dir_path.mkdir()
 
-    return dags_dir_path
\ No newline at end of file
+    return dags_dir_path
+
+
+def _str_to_datetime(dt: typing.Union[str, datetime]):
+    if isinstance(dt, datetime):
+        return dt
+    elif len(dt) <= 10:
+        return datetime.strptime(dt, "%Y-%m-%d")
+    else:
+        return datetime.strptime(dt, "%Y-%m-%d %H:%M:%S")
